namespace Syntriax.Engine.Core.Abstract;

/// <summary>
/// Indicates the object is an <see cref="IAssignable"/> with an assignable <see cref="IHierarchyObject"/> field.
/// </summary>
public interface IHasHierarchyObject : IAssignable
{
    /// <summary>
    /// Event triggered when the <see cref="IHierarchyObject"/> value has has been assigned a new value.
    /// </summary>
    event HierarchyObjectAssignedEventHandler? OnHierarchyObjectAssigned;

    /// <inheritdoc cref="IHierarchyObject" />
    IHierarchyObject HierarchyObject { get; }

    /// <summary>
    /// Assign a value to the <see cref="IHierarchyObject"/> field of this object.
    /// </summary>
    /// <param name="hierarchyObject">New <see cref="IHierarchyObject"/> to assign.</param>
    /// <returns> 
    /// <see cref="true"/>, if the value given assigned successfully assigned, <see cref="false"/> if not.
    /// </returns>
    bool Assign(IHierarchyObject hierarchyObject);

    delegate void HierarchyObjectAssignedEventHandler(IHasHierarchyObject sender);
}
